"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _reactRouterDom = require("react-router-dom");

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _tokens = _interopRequireWildcard(require("../../tokens"));

var _button = require("../../tokens/button");

var getPadding = function getPadding(_ref) {
  var size = _ref.size,
      hasIcon = _ref.hasIcon,
      hasText = _ref.hasText,
      buttonStyle = _ref.buttonStyle;

  if (hasIcon && !hasText) {
    return '5px';
  }

  if (buttonStyle === _tokens.ButtonConstants.styles.naked) {
    return '0';
  }

  switch (size) {
    case _tokens.ButtonConstants.sizes.xsmall:
      return '0 10px';

    case _tokens.ButtonConstants.sizes.small:
      return '0 10px';

    case _tokens.ButtonConstants.sizes.medium:
      return '0 20px';

    case _tokens.ButtonConstants.sizes.large:
      return '0 20px';

    default:
      return '0';
  }
};

var getBackgroundColor = function getBackgroundColor(_ref2, active) {
  var buttonStyle = _ref2.buttonStyle,
      color = _ref2.color,
      backgroundColor = _ref2.backgroundColor,
      disabled = _ref2.disabled;

  if (backgroundColor) {
    return backgroundColor;
  }

  if (buttonStyle === _tokens.ButtonConstants.styles.filled) {
    return _tokens["default"].button.colors[buttonStyle][color][(0, _button.getButtonState)(disabled, active)];
  }

  return 'transparent';
};

var getColor = function getColor(_ref3, active) {
  var buttonStyle = _ref3.buttonStyle,
      color = _ref3.color,
      disabled = _ref3.disabled;

  if (buttonStyle === _tokens.ButtonConstants.styles.filled) {
    return _tokens["default"].button.text.color;
  }

  return _tokens["default"].button.colors[buttonStyle][color][(0, _button.getButtonState)(disabled, active)];
};

var getHeight = function getHeight(_ref4) {
  var size = _ref4.size,
      hasIcon = _ref4.hasIcon,
      hasText = _ref4.hasText;

  if (hasIcon && !hasText) {
    return 'auto';
  }

  switch (size) {
    case _tokens.ButtonConstants.sizes.xsmall:
      return '26px';

    case _tokens.ButtonConstants.sizes.small:
      return '30px';

    case _tokens.ButtonConstants.sizes.medium:
      return '34px';

    case _tokens.ButtonConstants.sizes.large:
      return '50px';

    default:
      return 'auto';
  }
};

var getBorder = function getBorder(_ref5, active) {
  var buttonStyle = _ref5.buttonStyle,
      color = _ref5.color,
      disabled = _ref5.disabled;

  if (buttonStyle === _tokens.ButtonConstants.styles.outline) {
    return "1px solid ".concat(_tokens["default"].button.colors[buttonStyle][color][(0, _button.getButtonState)(disabled, active)]);
  }

  return 'none';
};

var StyledButton = _styledComponents["default"].button.withConfig({
  displayName: "ButtonWrapper__StyledButton",
  componentId: "sc-1oqrw78-0"
})(["display:flex;flex-direction:row;align-items:center;justify-content:center;cursor:pointer;text-decoration:none;background-color:", ";color:", ";height:", ";padding:", ";border:", ";opacity:", ";&:hover{color:", ";border:", ";background-color:", ";}", ""], function (props) {
  return getBackgroundColor(props, false);
}, function (props) {
  return getColor(props, false);
}, function (props) {
  return getHeight(props);
}, function (props) {
  return getPadding(props);
}, function (props) {
  return getBorder(props, false);
}, function (props) {
  return props.disabled ? 0.5 : 1;
}, function (props) {
  return getColor(props, true);
}, function (props) {
  return getBorder(props, true);
}, function (props) {
  return getBackgroundColor(props, true);
}, function (props) {
  return props.mixins;
});

var _default = {
  button: StyledButton,
  link: StyledButton.withComponent(_reactRouterDom.Link)
};
exports["default"] = _default;