"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.allComparators = exports.dateRangeComparators = exports.arrayComparators = exports.numberRangeComparators = exports.dateComparators = exports.numberComparators = exports.stringComparators = exports.comparators = exports.dateRangeExclusive = exports.dateRangeInclusive = exports.datesAfterAndIncluding = exports.datesAfter = exports.datesBeforeAndIncluding = exports.datesBefore = exports.rangeInclusive = exports.rangeExclusive = exports.includes = exports.subString = exports.match = exports.equal = exports.greaterThanOrEqualTo = exports.greaterThan = exports.lessThanOrEqualTo = exports.lessThan = exports.comparatorKeys = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _argumentTypeChecking = require("./argumentTypeChecking");

var _number, _string, _date;

var comparatorKeys = {
  lessThan: 'lessThan',
  lessThanOrEqualTo: 'lessThanOrEqualTo',
  greaterThan: 'greaterThan',
  greaterThanOrEqualTo: 'greaterThanOrEqualTo',
  match: 'match',
  equal: 'equal',
  subString: 'subString',
  includes: 'includes',
  rangeExclusive: 'rangeExclusive',
  rangeInclusive: 'rangeInclusive',
  datesBefore: 'datesBefore',
  datesBeforeAndIncluding: 'datesBeforeAndIncluding',
  datesAfter: 'datesAfter',
  datesAfterAndIncluding: 'datesAfterAndIncluding',
  dateRangeInclusive: 'dateRangeInclusive',
  dateRangeExclusive: 'dateRangeExclusive'
};
exports.comparatorKeys = comparatorKeys;

var lessThan = function lessThan(result, argument) {
  return (0, _argumentTypeChecking.areType)([result, argument], _argumentTypeChecking.isNumber) && result < argument;
};

exports.lessThan = lessThan;

var lessThanOrEqualTo = function lessThanOrEqualTo(result, argument) {
  return (0, _argumentTypeChecking.areType)([result, argument], _argumentTypeChecking.isNumber) && result <= argument;
};

exports.lessThanOrEqualTo = lessThanOrEqualTo;

var greaterThan = function greaterThan(result, argument) {
  return (0, _argumentTypeChecking.areType)([result, argument], _argumentTypeChecking.isNumber) && result > argument;
};

exports.greaterThan = greaterThan;

var greaterThanOrEqualTo = function greaterThanOrEqualTo(result, argument) {
  return (0, _argumentTypeChecking.areType)([result, argument], _argumentTypeChecking.isNumber) && result >= argument;
};

exports.greaterThanOrEqualTo = greaterThanOrEqualTo;

var equal = function equal(result, argument) {
  return (0, _argumentTypeChecking.areType)([result, argument], _argumentTypeChecking.isNumber) && result === argument;
};

exports.equal = equal;

var match = function match(result, argument) {
  return (0, _argumentTypeChecking.areType)([result, argument], _argumentTypeChecking.isString) && result.toLowerCase() === argument.toLowerCase();
};

exports.match = match;

var subString = function subString(result, argument) {
  return (0, _argumentTypeChecking.areType)([result, argument], _argumentTypeChecking.isString) && result.toLowerCase().includes(argument.toLowerCase());
};

exports.subString = subString;

var includes = function includes(result, argument) {
  return (0, _argumentTypeChecking.areType)([argument], _argumentTypeChecking.isArray) && argument.includes(result);
};

exports.includes = includes;

var rangeExclusive = function rangeExclusive(result, _ref) {
  var _ref2 = (0, _slicedToArray2["default"])(_ref, 2),
      min = _ref2[0],
      max = _ref2[1];

  if (!min && min !== 0) {
    return comparators.number.lessThan(result, max);
  }

  if (!max && max !== 0) {
    return comparators.number.greaterThan(result, min);
  }

  return (0, _argumentTypeChecking.areType)([min, max, result], _argumentTypeChecking.isNumber) && result > min && result < max;
};

exports.rangeExclusive = rangeExclusive;

var rangeInclusive = function rangeInclusive(result, _ref3) {
  var _ref4 = (0, _slicedToArray2["default"])(_ref3, 2),
      min = _ref4[0],
      max = _ref4[1];

  if (!min && min !== 0) {
    return comparators.number.lessThanOrEqualTo(result, max);
  }

  if (!max && max !== 0) {
    return comparators.number.greaterThanOrEqualTo(result, min);
  }

  return (0, _argumentTypeChecking.areType)([min, max, result], _argumentTypeChecking.isNumber) && result >= min && result <= max;
};

exports.rangeInclusive = rangeInclusive;

var datesBefore = function datesBefore(result, argument) {
  return (0, _argumentTypeChecking.areType)([result, argument], _argumentTypeChecking.isDateObject) && result.getTime() < argument.getTime();
};

exports.datesBefore = datesBefore;

var datesBeforeAndIncluding = function datesBeforeAndIncluding(result, argument) {
  return (0, _argumentTypeChecking.areType)([result, argument], _argumentTypeChecking.isDateObject) && result.getTime() <= argument.getTime();
};

exports.datesBeforeAndIncluding = datesBeforeAndIncluding;

var datesAfter = function datesAfter(result, argument) {
  return (0, _argumentTypeChecking.areType)([result, argument], _argumentTypeChecking.isDateObject) && result.getTime() > argument.getTime();
};

exports.datesAfter = datesAfter;

var datesAfterAndIncluding = function datesAfterAndIncluding(result, argument) {
  return (0, _argumentTypeChecking.areType)([result, argument], _argumentTypeChecking.isDateObject) && result.getTime() >= argument.getTime();
};

exports.datesAfterAndIncluding = datesAfterAndIncluding;

var dateRangeInclusive = function dateRangeInclusive(result, _ref5) {
  var _ref6 = (0, _slicedToArray2["default"])(_ref5, 2),
      startDate = _ref6[0],
      endDate = _ref6[1];

  if (!startDate) {
    return comparators.date.datesBeforeAndIncluding(result, endDate);
  }

  if (!endDate) {
    return comparators.date.datesAfterAndIncluding(result, startDate);
  }

  return (0, _argumentTypeChecking.areType)([result, startDate, endDate], _argumentTypeChecking.isDateObject) && result.getTime() >= startDate.getTime() && result.getTime() <= endDate.getTime();
};

exports.dateRangeInclusive = dateRangeInclusive;

var dateRangeExclusive = function dateRangeExclusive(result, _ref7) {
  var _ref8 = (0, _slicedToArray2["default"])(_ref7, 2),
      startDate = _ref8[0],
      endDate = _ref8[1];

  if (!startDate) {
    return comparators.date.datesBefore(result, endDate);
  }

  if (!endDate) {
    return comparators.date.datesAfter(result, startDate);
  }

  return (0, _argumentTypeChecking.areType)([result, startDate, endDate], _argumentTypeChecking.isDateObject) && result.getTime() > startDate.getTime() && result.getTime() < endDate.getTime();
};

exports.dateRangeExclusive = dateRangeExclusive;
var comparators = {
  number: (_number = {}, (0, _defineProperty2["default"])(_number, comparatorKeys.lessThan, lessThan), (0, _defineProperty2["default"])(_number, comparatorKeys.lessThanOrEqualTo, lessThanOrEqualTo), (0, _defineProperty2["default"])(_number, comparatorKeys.greaterThan, greaterThan), (0, _defineProperty2["default"])(_number, comparatorKeys.greaterThanOrEqualTo, greaterThanOrEqualTo), (0, _defineProperty2["default"])(_number, comparatorKeys.equal, equal), (0, _defineProperty2["default"])(_number, comparatorKeys.rangeExclusive, rangeExclusive), (0, _defineProperty2["default"])(_number, comparatorKeys.rangeInclusive, rangeInclusive), _number),
  string: (_string = {}, (0, _defineProperty2["default"])(_string, comparatorKeys.match, match), (0, _defineProperty2["default"])(_string, comparatorKeys.subString, subString), _string),
  array: (0, _defineProperty2["default"])({}, comparatorKeys.includes, includes),
  date: (_date = {}, (0, _defineProperty2["default"])(_date, comparatorKeys.datesBefore, datesBefore), (0, _defineProperty2["default"])(_date, comparatorKeys.datesBeforeAndIncluding, datesBeforeAndIncluding), (0, _defineProperty2["default"])(_date, comparatorKeys.datesAfter, datesAfter), (0, _defineProperty2["default"])(_date, comparatorKeys.datesAfterAndIncluding, datesAfterAndIncluding), (0, _defineProperty2["default"])(_date, comparatorKeys.dateRangeInclusive, dateRangeInclusive), (0, _defineProperty2["default"])(_date, comparatorKeys.dateRangeExclusive, dateRangeExclusive), _date)
};
exports.comparators = comparators;
var stringComparators = [comparators.string[comparatorKeys.match], comparators.string[comparatorKeys.subString]];
exports.stringComparators = stringComparators;
var numberComparators = [comparators.number[comparatorKeys.lessThan], comparators.number[comparatorKeys.lessThanOrEqualTo], comparators.number[comparatorKeys.greaterThan], comparators.number[comparatorKeys.greaterThanOrEqualTo], comparators.number[comparatorKeys.equal]];
exports.numberComparators = numberComparators;
var dateComparators = [comparators.date[comparatorKeys.datesBefore], comparators.date[comparatorKeys.datesBeforeAndIncluding], comparators.date[comparatorKeys.datesAfter], comparators.date[comparatorKeys.datesAfterAndIncluding]];
exports.dateComparators = dateComparators;
var numberRangeComparators = [comparators.number[comparatorKeys.rangeExclusive], comparators.number[comparatorKeys.rangeInclusive]];
exports.numberRangeComparators = numberRangeComparators;
var arrayComparators = [comparators.array[comparatorKeys.includes]];
exports.arrayComparators = arrayComparators;
var dateRangeComparators = [comparators.date[comparatorKeys.dateRangeInclusive], comparators.date[comparatorKeys.dateRangeExclusive]];
exports.dateRangeComparators = dateRangeComparators;
var allComparators = [].concat(stringComparators, numberComparators, dateComparators, numberRangeComparators, arrayComparators, dateRangeComparators);
exports.allComparators = allComparators;