"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = exports.getIconSize = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactRouter = require("react-router");

var _tokens = _interopRequireDefault(require("../../../tokens"));

var _navbar = require("../../../tokens/navbar");

var _Icon = _interopRequireDefault(require("../../Icon"));

var _ICONS = _interopRequireDefault(require("../../../constants/ICONS"));

var _NavbarSpinner = _interopRequireDefault(require("../NavbarSpinner"));

var _NavbarProgress = _interopRequireDefault(require("../NavbarProgress"));

var Styles = _interopRequireWildcard(require("./NavbarItem.styles"));

var getIconSize = function getIconSize(nested) {
  return nested ? 14 : 16;
};

exports.getIconSize = getIconSize;

var NavbarItem = function NavbarItem(_ref) {
  var icon = _ref.icon,
      iconSize = _ref.iconSize,
      iconColor = _ref.iconColor,
      label = _ref.label,
      path = _ref.path,
      expanded = _ref.expanded,
      nested = _ref.nested,
      groupHeader = _ref.groupHeader,
      showNestedItems = _ref.showNestedItems,
      hightlightOnHover = _ref.hightlightOnHover,
      toggleNestedItems = _ref.toggleNestedItems,
      onClick = _ref.onClick,
      closeNavbar = _ref.closeNavbar,
      closeNavbarOnClick = _ref.closeNavbarOnClick,
      inContentBlock = _ref.inContentBlock,
      showSpinner = _ref.showSpinner,
      showProgress = _ref.showProgress,
      progress = _ref.progress,
      collapsedComponent = _ref.collapsedComponent,
      expandedComponent = _ref.expandedComponent,
      pathname = _ref.location.pathname;
  var activePath = pathname.startsWith(path);
  var Container = path ? path.startsWith('http') ? Styles.NavbarItemExternalLink : Styles.NavbarItemLink : Styles.NavbarItemDiv;

  var handleOnClick = function handleOnClick(event) {
    onClick && onClick(event);
    closeNavbarOnClick && closeNavbar && closeNavbar();
  };

  var handleGroupHeaderToggle = function handleGroupHeaderToggle(event) {
    event.preventDefault();
    event.stopPropagation();
    toggleNestedItems && toggleNestedItems();
  };

  var Collapsed = function Collapsed() {
    return collapsedComponent ? collapsedComponent : icon ? _react["default"].createElement(_Icon["default"], {
      icon: icon,
      size: iconSize || getIconSize(nested),
      color: iconColor || (0, _navbar.getItemColor)(inContentBlock, activePath)
    }) : null;
  };

  var Expanded = function Expanded() {
    return expandedComponent ? expandedComponent : label ? _react["default"].createElement("span", null, label) : null;
  };

  return _react["default"].createElement(Container, {
    to: path,
    href: path,
    target: path && path.startsWith('http') ? '_blank' : '',
    onClick: handleOnClick,
    activePath: activePath,
    showNestedItems: showNestedItems,
    nested: nested,
    groupHeader: groupHeader,
    inContentBlock: inContentBlock,
    hightlightOnHover: hightlightOnHover,
    iconSize: iconSize || getIconSize(nested),
    "data-qa-id": "NavbarItem"
  }, _react["default"].createElement(Styles.ActiveItem, {
    expanded: expanded,
    hightlightOnHover: hightlightOnHover,
    showNestedItems: showNestedItems,
    groupHeader: groupHeader,
    activePath: activePath
  }), _react["default"].createElement(Styles.Collapsed, {
    nested: nested,
    expanded: expanded,
    iconSize: iconSize || getIconSize(nested),
    "data-qa-id": "NavbarItem__Collapsed"
  }, _react["default"].createElement(Collapsed, null), showSpinner && _react["default"].createElement(_NavbarSpinner["default"], null)), _react["default"].createElement(Styles.Expanded, {
    inContentBlock: inContentBlock,
    activePath: activePath,
    expanded: expanded,
    nested: nested,
    "data-qa-id": "NavbarItem__Expanded"
  }, _react["default"].createElement(Expanded, null), groupHeader && _react["default"].createElement("span", {
    onClick: handleGroupHeaderToggle
  }, _react["default"].createElement(_Icon["default"], {
    icon: _ICONS["default"]['right-chevron'],
    color: iconColor || _tokens["default"].navbar.item.color[pathname.startsWith(path) ? 'active' : 'default'],
    size: 8,
    mixins: [Styles.ToggleChevron(showNestedItems)]
  }))), showProgress && _react["default"].createElement(_NavbarProgress["default"], {
    expanded: expanded,
    progress: progress
  }));
};

NavbarItem.displayName = 'NavbarItem';
NavbarItem.defaultProps = {
  closeNavbarOnClick: true,
  hightlightOnHover: true
};

var _default = (0, _reactRouter.withRouter)(NavbarItem);

exports["default"] = _default;