"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getPositionFromPercentage = getPositionFromPercentage;
exports.getPercentageFromPosition = getPercentageFromPosition;
exports.getValueFromPosition = getValueFromPosition;
exports.getPercentageFromValue = getPercentageFromValue;
exports.getStepValueFromValue = getStepValueFromValue;
exports.getPositionFromEvent = getPositionFromEvent;

var clamp = function clamp(value, min, max) {
  return Math.min(Math.max(value, min), max);
};

function getPositionFromPercentage(sizePerc, clientRect) {
  if (clientRect) {
    var length = clientRect.width;
    var position = sizePerc * length;
    return position || 0;
  }

  return 0;
}

function getPercentageFromPosition(position, clientRect) {
  var length = clientRect.width;
  var sizePerc = position.x / length;
  return sizePerc || 0;
}

function getValueFromPosition(position, minValue, maxValue, clientRect) {
  var sizePerc = getPercentageFromPosition(position, clientRect);
  var valueDiff = maxValue - minValue;
  return minValue + valueDiff * sizePerc;
}

function getPercentageFromValue(value, minValue, maxValue) {
  var validValue = clamp(value, minValue, maxValue);
  var valueDiff = maxValue - minValue;
  var valuePerc = (validValue - minValue) / valueDiff;
  return valuePerc || 0;
}

function getStepValueFromValue(value, valuePerStep, currentValue) {
  if (currentValue) {
    if (value < currentValue && currentValue - valuePerStep < value) {
      return Math.floor(value / valuePerStep) * valuePerStep;
    }

    if (value > currentValue && currentValue + valuePerStep > value) {
      return Math.ceil(value / valuePerStep) * valuePerStep;
    }
  }

  return Math.round(value / valuePerStep) * valuePerStep;
}

function getPositionFromEvent(event, clientRect) {
  var length = clientRect.width;

  var _ref = event.touches ? event.touches[0] : event,
      clientX = _ref.clientX;

  return {
    x: clamp(clientX - clientRect.left, 0, length),
    y: 0
  };
}